@@ -49,7 +49,7 @@ checkresiduals <- function(object, lag, df=NULL, test, plot=TRUE, ...) {
   else {
     showtest <- FALSE
   }
-  
+
   # Extract residuals
   if (is.element("ts", class(object)) | is.element("numeric", class(object))) {
     residuals <- object
@@ -62,7 +62,7 @@ checkresiduals <- function(object, lag, df=NULL, test, plot=TRUE, ...) {
   if (length(residuals) == 0L) {
     stop("No residuals found")
   }
-  
+
   if ("ar" %in% class(object)) {
     method <- paste("AR(", object$order, ")", sep = "")
   } else if (!is.null(object$method)) {
@@ -106,7 +106,7 @@ checkresiduals <- function(object, lag, df=NULL, test, plot=TRUE, ...) {
     warning("The fitted degrees of freedom is based on the model used for the seasonally adjusted data.")
   }
   df <- modeldf(object)
-  
+
   if (missing(lag)) {
     lag <- ifelse(freq > 1, 2 * freq, 10)
     lag <- min(lag, round(length(residuals)/5))
@@ -118,7 +118,8 @@ checkresiduals <- function(object, lag, df=NULL, test, plot=TRUE, ...) {
       # Do Breusch-Godfrey test
       BGtest <- lmtest::bgtest(object, order = lag)
       BGtest$data.name <- main
-      print(BGtest)
+      #print(BGtest)
+      return(BGtest)
     }
     else {
       # Do Ljung-Box test
@@ -128,6 +129,7 @@ checkresiduals <- function(object, lag, df=NULL, test, plot=TRUE, ...) {
       names(LBtest$statistic) <- "Q*"
       print(LBtest)
       cat(paste("Model df: ", df, ".   Total lags used: ", lag, "\n\n", sep = ""))
+      return(invisible(LBtest))
     }
   }
 }
@@ -146,11 +148,11 @@ modeldf.ets <- function(object, ...){
 }
 
 modeldf.Arima <- function(object, ...){
-  length(object$coef)
+  sum(arimaorder(object)[c("p","q","P","Q")], na.rm = TRUE)
 }
 
 modeldf.bats <- function(object, ...){
-  length(object$parameters$vect) + NROW(object$seed.states)
+  length(object$parameters$vect)
 }
 
 modeldf.lm <- function(object, ...){
@@ -163,4 +165,4 @@ modeldf.lagwalk <- function(object, ...){
 
 modeldf.meanf <- function(object, ...){
   1
-}
\ No newline at end of file
+}
