@@ -63,7 +63,7 @@ spline.loglik <- function(beta, y, cc=1e2) {
 #' \code{\link[stats]{smooth.spline}} is used. If \code{method="mle"}, the
 #' maximum likelihood method from Hyndman et al (2002) is used.
 #' @param x Deprecated. Included for backwards compatibility.
-#' @inheritParams forecast
+#' @inheritParams forecast.ts
 #' @return An object of class "\code{forecast}".
 #'
 #' The function \code{summary} is used to obtain and print a summary of the
@@ -133,7 +133,7 @@ splinef <- function(y, h=10, level=c(80, 95), fan=FALSE, lambda=NULL, biasadj=FA
   {
     splinefit <- smooth.spline(1:n, x, cv = FALSE, spar = NULL)
     sfits <- splinefit$y
-    beta.est <- splinefit$lambda * (n - 1) ^ 3 / n ^ 3
+    beta.est <- pmax(1e-7, splinefit$lambda * (n - 1) ^ 3 / n ^ 3)
   }
 
   # Compute matrices for optimal beta
